@@ -8,7 +8,7 @@
 
 void Generator::baseclassHeader() const
 {
-    if (d_arg.option(0, "no-baseclass-header"))
+    if (d_options("no-baseclass-header"))
         return;
 
     ofstream out;
