@@ -8,4 +8,6 @@ char Options::s_defaultLexFunctionName[]        = "lex";
 char Options::s_defaultTargetDirectory[]        = "";
 char Options::s_defaultClassName[]              = "Scanner";
 
-Options Options::s_options;
+void (*Options::s_regexCall)(char const *funName) = Options::nop;
+
+Options *Options::s_options = 0;
