@@ -1,16 +1,23 @@
 #ifndef INCLUDED_OPTIONS_
 #define INCLUDED_OPTIONS_
 
+#include <iostream>
 #include <string>
-#include <bobcat/a2x>
+
+namespace FBB
+{
+    class Arg;
+}
 
 class Options
 {
+    FBB::Arg const &d_arg;
     std::string d_baseClassHeaderPath;
     std::string d_baseClassSkeleton;
     std::string d_classHeaderPath;
     std::string d_className;
     std::string d_classSkeleton;
+    std::string d_constructionPath;
     std::string d_filenames;
     std::string d_implementationHeaderPath;
     std::string d_implementationSkeleton;
@@ -22,11 +29,15 @@ class Options
     std::string d_nameSpace;
     std::string d_skeletonDirectory;
     std::string d_targetDirectory;
+    std::string d_infile;
 
     bool d_interactive;
     bool d_lines;
     bool d_print;
     bool d_debug;
+    bool d_matchedRules;
+    bool d_verbose;
+    bool d_caseSensitive;
 
     enum 
     {
@@ -41,18 +52,26 @@ class Options
     static char s_defaultLexfunSource[];
     static char s_defaultTargetDirectory[];
 
-    static Options s_options;
+    static Options *s_options;
+    static void (*s_regexCall)(char const *funName);
 
     public:
+        static Options &init(FBB::Arg const &arg);
         static Options &instance();
 
         Options(Options const &other) = delete;
 
+        bool caseSensitive() const;
         bool debug() const;
         bool interactive() const;
         bool lines() const;
         bool print() const;
+        bool verbose() const;
+        bool operator()(int opt) const;
+        bool operator()(char const *opt) const;
+
         std::size_t maxDepth() const;
+
         std::string baseclassHeaderName() const;
         std::string classHeaderName() const;
         std::string const &baseclassHeaderPath() const;
@@ -69,10 +88,13 @@ class Options
         std::string const &lexSkeleton() const;
         std::string const &lexSourcePath() const;
         std::string const &nameSpace() const;
+        std::string const &infile() const;
+        std::string const &constructionPath() const;
         std::string implementationHeaderName() const;
         void setBaseClassHeaderPath(std::string const &name);
         void setClassHeaderPath(std::string const &name);
         void setClassName(std::string const &name);
+        void setCaseInsensitive();
         void setDebug();
         void setFilenames(std::string const &name);
         void setImplementationHeaderPath(std::string const &name);
@@ -87,24 +109,54 @@ class Options
         void setSkeletonDirectory(std::string const &name);
         void setTargetDirectory(std::string const &name);
 
+        static void regexCall(char const *funname);
 
         void setAccessorVariables();
 
     private:
-        Options();
+        Options(FBB::Arg const &arg);
 
         std::string undelimit(std::string const &str);
         void setPath(std::string *target, std::string const &name);
         void setPath(std::string *dest, int optChar, bool targetDirOption, 
                       char const *optionName, std::string const &className, 
                       char const *suffix);
+
+        static void nop(char const *funName);
+        static void show(char const *funName);
+
 };
 
+inline Options &Options::instance()
+{
+    return *s_options;
+}
+
+inline void Options::show(char const *funName)
+{
+    std::cout << '\t' << funName << '\n';
+}
+
+inline void Options::regexCall(char const *funName)
+{
+    (*s_regexCall)(funName);
+}
+
 inline size_t Options::maxDepth() const
 {
     return d_maxDepth;
 }
 
+inline bool Options::caseSensitive() const
+{
+    return d_caseSensitive;
+}
+
+inline std::string const &Options::constructionPath() const
+{
+    return d_constructionPath;
+}
+
 inline std::string const &Options::inputInterface() const
 {
     return d_inputInterface;
@@ -175,6 +227,11 @@ inline std::string const &Options::nameSpace() const
     return d_nameSpace;
 }
 
+inline std::string const &Options::infile() const
+{
+    return d_infile;
+}
+
 inline void Options::setInputImplementationPath(std::string const &name)
 {
     setPath(&d_inputImplementation, name);
@@ -210,6 +267,11 @@ inline void Options::setInteractive()
     d_interactive = true;
 }
 
+inline void Options::setCaseInsensitive()
+{   
+    d_caseSensitive = false;
+}
+
 inline void Options::setLines(bool yesNo)
 {   
     d_lines = yesNo;
@@ -230,6 +292,12 @@ inline bool Options::interactive() const
     return d_interactive;
 }
 
+
+inline bool Options::verbose() const
+{   
+    return d_verbose;
+}
+
 inline bool Options::print() const
 {   
     return d_print;
@@ -251,3 +319,4 @@ inline bool Options::debug() const
 
 
 
+
