@@ -215,7 +215,7 @@ void \@Base::accept(size_t nChars)          // old name: less
 void \@Base::determineMatchedSize(FinData const &final)
 {
     size_t length = final.matchLen;
-    if (final.tailCount != UINT_MAX)
+    if (final.tailCount != std::numeric_limits<size_t>::max())
         length -= final.tailCount;
 
     d_input.reRead(d_matched, length);      // reread the tail section
@@ -228,13 +228,13 @@ void \@Base::determineMatchedSize(FinData const &final)
   // d_atBOL is updated. Finally the rule index is returned.
 size_t \@Base::matched__(size_t ch)
 {
-$insert 4 debug.action "MATCH"
+$insert 4 debug "MATCH"
     d_input.reRead(ch);
 
     if (!d_atBOL)
-        d_final.atBOL.rule = UINT_MAX;
+        d_final.atBOL.rule = std::numeric_limits<size_t>::max();
 
-    FinData &final = d_final.atBOL.rule == UINT_MAX ? 
+    FinData &final = d_final.atBOL.rule == std::numeric_limits<size_t>::max() ? 
                             d_final.notAtBOL
                         :
                             d_final.atBOL;
@@ -243,7 +243,7 @@ $insert 4 debug.action "MATCH"
 
     d_atBOL = *d_matched.rbegin() == '\n';
 
-$insert 4 debug.action "match buffer contains `" << d_matched << "'"
+$insert 4 debug "match buffer contains `" << d_matched << "'"
 
     return final.rule;
 }
@@ -253,6 +253,7 @@ size_t \@Base::getRange__(int ch)       // using int to prevent casts
     if (ch != AT_EOF)
         d_sawEOF = false;
 
+$insert caseCheck
     return ch == AT_EOF ? static_cast<size_t>(s_rangeOfEOF__) : s_ranges__[ch];
 }
 
@@ -261,7 +262,7 @@ size_t \@Base::getRange__(int ch)       // using int to prevent casts
   // are updated.
 void \@Base::continue__(int ch)
 {
-$insert 4 debug.action "CONTINUE, NEXT STATE: " << d_nextState
+$insert 4 debug "CONTINUE, NEXT STATE: " << d_nextState
     d_state = d_nextState;
 
     if (ch != AT_EOF)
@@ -270,7 +271,7 @@ $insert 4 debug.action "CONTINUE, NEXT STATE: " << d_nextState
 
 void \@Base::echoCh__(size_t ch)
 {
-$insert 4 debug.action "ECHO_CH" 
+$insert 4 debug "ECHO_CH" 
     *d_out << static_cast<char>(ch);
     d_atBOL = ch == '\n';
 }
@@ -283,7 +284,7 @@ $insert 4 debug.action "ECHO_CH"
    // rules and that char is then echoed
 void \@Base::echoFirst__(size_t ch)
 {
-$insert 4 debug.action "ECHO_FIRST"
+$insert 4 debug "ECHO_FIRST"
     d_input.reRead(ch);
     d_input.reRead(d_matched, 1);
     echoCh__(d_matched[0]);
@@ -293,7 +294,7 @@ $insert 4 debug.action "ECHO_FIRST"
     //  If the s_rfc__ element has its COUNT flag set then set the 
     // d_tailCount[rule] value to the element's tailCount value, if it has its 
     // INCREMENT flag set then increment d_tailCount[rule]
-    //  If neither was set set the d_tailCount[rule] to UINT_MAX
+    //  If neither was set set the d_tailCount[rule] to numeric_limits<size_t>::max()
     // 
     // If the s_rfc__ element has its FINAL flag set then store the rule number
     // in d_final.second. If it has its FINAL + BOL flags set then store the
@@ -315,7 +316,7 @@ void \@Base::inspectRFCs__()
         if (flag & INCREMENT)
             ++d_tailCount[rule];
         else 
-            d_tailCount[rule] = (flag & COUNT) ? rfc[ACCCOUNT] : UINT_MAX;
+            d_tailCount[rule] = (flag & COUNT) ? rfc[ACCCOUNT] : std::numeric_limits<size_t>::max();
 
         if (flag & FINAL)
         {
@@ -327,8 +328,8 @@ void \@Base::inspectRFCs__()
 
 void \@Base::reset__()
 {
-    d_final = Final { {UINT_MAX, UINT_MAX, UINT_MAX }, 
-                      {UINT_MAX, UINT_MAX, UINT_MAX } };
+    d_final = Final { {std::numeric_limits<size_t>::max(), std::numeric_limits<size_t>::max(), std::numeric_limits<size_t>::max() }, 
+                      {std::numeric_limits<size_t>::max(), std::numeric_limits<size_t>::max(), std::numeric_limits<size_t>::max() } };
     d_state = 0;
     d_return = true;
 
@@ -341,12 +342,12 @@ void \@Base::reset__()
 int \@::executeAction__(size_t ruleIdx)
 try
 {
-$insert 4 debug.action  "Executing actions of rule " << ruleIdx
+$insert 4 debug.R  "Executing actions of rule " << ruleIdx
     switch (ruleIdx)
     {
 $insert 8 actions
     }
-$insert 4 debug.action "Rule " << ruleIdx << " did not do 'return'"
+$insert 4 debug "Rule " << ruleIdx << " did not do 'return'"
     noReturn__();
     return 0;
 }
@@ -393,7 +394,7 @@ int \@::lex__()
             break;
 
             case ActionType__::RETURN:
-$insert 16 debug.action  "EOF_REACHED"
+$insert 16 debug  "EOF_REACHED"
                 if (!popStream())
                     return 0;
             continue;
