@@ -6,26 +6,30 @@ void usage(string const &program_name)
 {
     cout << 
     "\n" <<
-    program_name << " by Richard Berendsen (rwberendsen@gmail.com),\n"
-    "        Frank B. Brokken (f.b.brokken@rug.nl) and\n"
-    "        Jean-Paul van Oosten (j.p.van.oosten@rug.nl)\n"
+    program_name << " by Frank B. Brokken (f.b.brokken@rug.nl)\n"
+    "                 and Jean-Paul van Oosten (j.p.van.oosten@rug.nl)\n"
     "\n"
     "Lexical Scanner Generator V "  << version << "\n"
     "Copyright (c) GPL " << year << ". NO WARRANTY.\n"
     "\n"
-    "Usage: " << program_name << " [OPTIONS] FILENAME\n"
+    "Usage: " << program_name << " [options] infile\n"
     "Where:\n"
-    "  [OPTIONS] - zero or more optional arguments, where [OPTIONS] are:\n"
+    "  [options] - zero or more optional arguments, where [options] are:\n"
     "   --baseclass-header=<filename> (-b):\n"
     "           filename for the base class definition.\n"
     "   --baseclass-skeleton=<path> (-B):\n"
-    "            location of the baseclass header skeleton.\n"
+    "           location of the baseclass header skeleton.\n"
+    "   --case-insensitive:\n"
+    "           regexes disregard letter casing.\n"
     "   --class-header=<filename> (-c):\n"
     "           filename for the class definition.\n"
     "   --class-name=<classname> (-c):\n"
     "           class name of the generated scanner class.\n"
     "   --class-skeleton=<path> (-C):\n"
     "            location of the class header skeleton.\n"
+    "   --construction (-K):\n"
+    "           write information about the rules and DFA-creation on\n"
+    "           'infile'.output\n"
     "   --debug (-d):\n"
     "           generates debug output statements in the lex function\n"
     "   --force-class-header:\n"
@@ -48,6 +52,9 @@ void usage(string const &program_name)
     "            filename for the lex function's source.\n"
     "   --lines:\n"
     "            add #line preprocessor directives to the lex function.\n"
+    "   --matched-rules (-R):\n"
+    "            show the numbers of matched rules on stdout\n"
+    "            (implied by --debug)\n"
     "   --max-depth=<maxDepth> (-m):\n"
     "            set the max. scanner specification file inclusion depth.\n"
     "   --namespace=<namespace> (-n):\n"
@@ -65,6 +72,8 @@ void usage(string const &program_name)
     "   --print-tokens (-t):\n"
     "           the print() member of the generated parser class displays\n"
     "           the tokens and their corresponding matched text.\n"
+    "   --regex-calls:\n"
+    "           show function call order when parsing regexes\n"
     "   --show-filenames (-F):\n"
     "            display the names of generated files.\n"
     "   --skeleton-directory=<path> (-S):\n"
@@ -72,12 +81,11 @@ void usage(string const &program_name)
     "   --target-directory=<path>:\n"
     "            target directory for generated files.\n"
     "   --verbose (-V):\n"
-    "           output information about DFA-creation and code generation,\n"
-    "           specify repeatedly for more output\n"
+    "           provide additional info on stdout\n"
     "   --version (-v):\n"
     "           display " << program_name << "'s version and terminate.\n"
     "\n"
-    "  FILENAME  - name of the file containing the scanner specifications\n"
+    "  `infile' - name of the file containing the scanner specifications\n"
 
     << '\n';
 }
